@@ -1,15 +1,16 @@
 package Tests::Mock;
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 use strict;
 use warnings;
 use base 'Test::Class';
 use Test::Class::Most;
+use Test::Moose;
 
 use aliased 'Test::Mock::Context' => 'MockContext';
 
 {
     package ToMock;
-our $VERSION = '0.02';
+our $VERSION = '0.03';
     use Moose;
 
     sub explode { }
@@ -17,11 +18,20 @@ our $VERSION = '0.02';
     sub tick    { }
 }
 
+{
+    package ToMock::Role;
+our $VERSION = '0.03';
+    use Moose::Role;
+
+    sub dance { }
+}
+
 sub startup : Tests(setup => 1)
 {
     my $test = shift;
     $test->{context} = MockContext->new;
     $test->{mock}    = $test->{context}->mock('ToMock');
+    $test->{role}    = $test->{context}->mock('ToMock::Role');
 }
 
 sub replay_nothing : Test
@@ -151,4 +161,18 @@ sub can_return_data : Test(2)
     is $wire_cut, 'red wire';
 }
 
+sub can_mock_roles : Test(2)
+{
+    my $test = shift;
+    my $context = $test->{context};
+    my $mock = $test->{role};
+
+    $context->expect($mock, 'dance');
+
+    $mock->dance;
+
+    does_ok $mock, 'ToMock::Role';
+    ok $context->satisfied;
+}
+
 1;
